# lime-circle 進度環
- 基於uniapp vue3 提供css3和canvas兩種渲染方式的的環形進度條
- Q群 1169785031

## 使用
- 導入插件後直接使用

### 基礎使用
- 默認使用css實現的方式，在不支持css方案的手機會自動切為canvas

```html
<l-circle v-model:current="modelVale" :percent="target">
	<text>{{modelVale}}%</text>
</l-circle>
```
```js
const target = ref(50)
const modelVale = ref(0)
```

### canvas渲染
- 也可以主動設置 `canvas` 使用canvas方式渲染

```html
<l-circle v-model:current="modelVale" :percent="target" canvas>
	<text>{{modelVale}}%</text>
</l-circle>
```
```js
const target = ref(50)
const modelVale = ref(0)
```

### 查看示例
導入後直接使用這個標簽查看演示效果

```html
// 代碼位於 uni_modules/lime-circle/compoents/lime-circle
<lime-circle />
```


### 插件標簽
- 默認 l-circle 為 component
- 默認 lime-circle 為 demo

### 關於vue2的使用方式
- 插件使用了`composition-api`, 如果妳希望在vue2中使用請按官方的教程[vue-composition-api](https://uniapp.dcloud.net.cn/tutorial/vue-composition-api.html)配置
- 關鍵代碼是: 在main.js中 在vue2部分加上這壹段即可,官方是把它單獨成了壹個文件.

```js
// main.js vue2
import Vue from 'vue'
import VueCompositionAPI from '@vue/composition-api'
Vue.use(VueCompositionAPI)
```
另外插件也用到了TS，vue2可能會遇過官方的TS版本過低的問題,找到HX目錄下的`compile-typescript`目錄
```cmd
// \HBuilderX\plugins\compile-typescript
yarn add typescript -D
- or - 
npm install typescript -D
```

#### 使用

```html
<l-circle :current.sync="modelVale" :percent="target">
	<text>{{modelVale}}%</text>
</l-circle>
<button @tap="onClick(20)">+</button>
<button @tap="onClick(-20)">-</button>
```
```js
export default {
	data() {
		return {
			modelVale: 0,
			target: 50
		}
	},
	methods: {
		onClick(number) {
			this.target = Math.max(Math.min(100, this.target + number), 0)
		}
	}
}
```


## API

### Props

| 參數                       | 說明                                                         | 類型             | 默認值       |
| --------------------------| ------------------------------------------------------------ | ---------------- | ------------ |
| percent                   | 進度環目標值                                                    | <em>number</em>  | `0`        |
| v-model:current           | 進度環當前值(從上壹個percent到當前percent的過渡值)              | <em>number</em>  | `-`        |
| size                      | 進度環尺寸                                                     | <em>string</em>  | `120px`     |
| lineCap           		| 進度條頂端形態 , 可選值 `butt` `round`                           | <em>string</em>  | `round`      |
| strokeWidth           	| 進度條寬度                   									 | <em>number，string</em>  | `6`      |
| strokeColor           	| 進度條顏色, 若為數組即為漸變色（漸變色值僅支持hex）           	| <em>string、string[]</em>  | `#2db7f5`  |
| trailWidth             	| 軌道環線寬度          					                     	| <em>number，string</em>  | `6`  |
| trailColor             	| 軌道環線顏色         					                     	| <em>string</em>  | `#eaeef2`  |
| dashboard             	| 是否為儀表盤樣式        					                     | <em>boolean</em>  | `false`  |
| clockwise             	| 是否為順時針      					                    		 | <em>boolean</em>  | `true`  |
| duration             		| 變化過渡時間, ms      					                    	| <em>number</em>  | `300`  |
| max             		    | 總長度（例如：max 100,percent 50 時，進度為50%）   				| <em>number</em>  | `100`  |
| canvas             		| 是否使用canvas渲染  					                    	| <em>boolean</em>  | `false`  |


## 打賞

如果妳覺得本插件，解決了妳的問題，贈人玫瑰，手留余香。  
![](https://testingcf.jsdelivr.net/gh/liangei/image@1.9/alipay.png)
![](https://testingcf.jsdelivr.net/gh/liangei/image@1.9/wpay.png)