import { func, date, url } from '@/uni_modules/uv-ui-tools/libs/function/test.js'
import { error, timeFormat, priceFormat } from '@/uni_modules/uv-ui-tools/libs/function/index.js'
export default {
    computed: {
        // 經處理後需要顯示的值
        value() {
            const {
                text,
                mode,
                format,
                href
            } = this
            // 價格類型
            if (mode === 'price') {
                // 如果text不為金額進行提示
                if (!/^\d+(\.\d+)?$/.test(text)) {
                    error('金額模式下，text參數需要為金額格式');
                }
                // 進行格式化，判斷用戶傳入的format參數為正則，或者函數，如果沒有傳入format，則使用默認的金額格式化處理
                if (func(format)) {
                    // 如果用戶傳入的是函數，使用函數格式化
                    return format(text)
                }
                // 如果format非正則，非函數，則使用默認的金額格式化方法進行操作
                return priceFormat(text, 2)
            } if (mode === 'date') {
                // 判斷是否合法的日期或者時間戳
                !date(text) && error('日期模式下，text參數需要為日期或時間戳格式')
                // 進行格式化，判斷用戶傳入的format參數為正則，或者函數，如果沒有傳入format，則使用默認的格式化處理
                if (func(format)) {
                    // 如果用戶傳入的是函數，使用函數格式化
                    return format(text)
                } if (format) {
                    // 如果format非正則，非函數，則使用默認的時間格式化方法進行操作
                    return timeFormat(text, format)
                }
                // 如果沒有設置format，則設置為默認的時間格式化形式
                return timeFormat(text, 'yyyy-mm-dd')
            } if (mode === 'phone') {
                // 判斷是否合法的手機號
                // !mobile(text) && error('手機號模式下，text參數需要為手機號碼格式')
                if (func(format)) {
                    // 如果用戶傳入的是函數，使用函數格式化
                    return format(text)
                } if (format === 'encrypt') {
                    // 如果format為encrypt，則將手機號進行星號加密處理
                    return `${text.substr(0, 3)}****${text.substr(7)}`
                }
                return text
            } if (mode === 'name') {
                // 判斷是否合法的字符粗
                !(typeof (text) === 'string') && error('姓名模式下，text參數需要為字符串格式')
                if (func(format)) {
                    // 如果用戶傳入的是函數，使用函數格式化
                    return format(text)
                } if (format === 'encrypt') {
                    // 如果format為encrypt，則將姓名進行星號加密處理
                    return this.formatName(text)
                }
                return text
            } if (mode === 'link') {
                // 判斷是否合法的字符粗
                !url(href) && error('超鏈接模式下，href參數需要為URL格式')
                return text
            }
            return text
        }
    },
    methods: {
        // 默認的姓名脫敏規則
        formatName(name) {
            let value = ''
            if (name.length === 2) {
                value = name.substr(0, 1) + '*'
            } else if (name.length > 2) {
                let char = ''
                for (let i = 0, len = name.length - 2; i < len; i++) {
                    char += '*'
                }
                value = name.substr(0, 1) + char + name.substr(-1, 1)
            } else {
                value = name
            }
            return value
        }
    }
}
